@@ -147,7 +147,13 @@ export class Component {
           ) {
             if (!this.attachedDbEvents.some((e) => e.isSame(element))) {
               this.attachedDbEvents.push(element);
-              addDbEventListener(this, element.el, element.field.eventType);
+              addDbEventListener(this, element);
+
+              // If a field is lazy, also add an event listener for input for dirty states
+              if (element.field.isLazy) {
+                // This input event for isLazy will be stopped after dirty is checked when the event fires
+                addDbEventListener(this, element, "input");
+              }
             }
 
             if (!this.dbEls.some((e) => e.isSame(element))) {
@@ -160,7 +166,13 @@ export class Component {
           ) {
             if (!this.attachedModelEvents.some((e) => e.isSame(element))) {
               this.attachedModelEvents.push(element);
-              addModelEventListener(this, element.el, element.model.eventType);
+              addModelEventListener(this, element);
+
+              // If a model is lazy, also add an event listener for input for dirty states
+              if (element.model.isLazy) {
+                // This input event for isLazy will be stopped after dirty is checked when the event fires
+                addModelEventListener(this, element, "input");
+              }
             }
 
             if (!this.modelEls.some((e) => e.isSame(element))) {
@@ -190,6 +202,7 @@ export class Component {
               ) {
                 this.attachedEventTypes.push(action.eventType);
                 addActionEventListener(this, action.eventType);
+                element.events.push(action.eventType);
               }
             }
           });
